


#ifndef __PANEL_APPLET_ENUMS_H__
#define __PANEL_APPLET_ENUMS_H__

G_BEGIN_DECLS


/* --- /usr/src/ports/gnome-panel/gnome-panel-3.22.0-1.x86_64/src/gnome-panel-3.22.0/libpanel-applet/panel-applet.h --- */
#define PANEL_TYPE_PANEL_APPLET_ORIENT panel_applet_orient_get_type()
GType panel_applet_orient_get_type (void);
#define PANEL_TYPE_PANEL_APPLET_FLAGS panel_applet_flags_get_type()
GType panel_applet_flags_get_type (void);
G_END_DECLS

#endif /* __PANEL_APPLET_ENUMS_H__ */



